package com.ruoyi.app.service;

import java.util.List;

import com.ruoyi.app.DTO.RegionTreeDTO;
import com.ruoyi.app.model.Region;

/**
 * 区域Service接口
 * 
 * @author coede
 * @date 2025-03-19
 */
public interface IRegionService 
{
    /**
     * 查询区域
     * 
     * @param id 区域主键
     * @return 区域
     */
    public Region selectRegionById(Long id);

    /**
     * 查询区域列表
     * 
     * @param region 区域
     * @return 区域集合
     */
    public List<Region> selectRegionList(Region region);


    /**
     * 查询区域设备树列表
     *
     * @param region 区域
     * @return 区域集合
     */
    public List<RegionTreeDTO> selectRegionTreeList(Region region);

    /**
     * 校验待区域名称是否唯一
     *
     * @param  region 区域
     * @return 结果
     */
    public boolean checkRegionNameUnique(Region region);

    /**
     * 新增区域
     * 
     * @param region 区域
     * @return 结果
     */
    public int insertRegion(Region region);

    /**
     * 修改区域
     * 
     * @param region 区域
     * @return 结果
     */
    public int updateRegion(Region region);

    /**
     * 批量删除区域
     * 
     * @param ids 需要删除的区域主键集合
     * @return 结果
     */
    public int deleteRegionByIds(Long[] ids);

    /**
     * 删除区域信息
     * 
     * @param id 区域主键
     * @return 结果
     */
    public int deleteRegionById(Long id);
}
